@@ -30,6 +30,8 @@ import subprocess
 import tempfile
 import datetime
 
+import six
+
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 
@@ -122,6 +124,11 @@ def get_file_type(filename):
 
 
 def normalize_token(token):
+    """
+    Normalize internal token name (e.g. empty string, 'internal',
+    'Internal Key Storage Token') into None. Other token names
+    will be unchanged.
+    """
     if not token:
         return None
 
@@ -469,6 +476,13 @@ class NSSDatabase(object):
             if key_type:
                 cmd.extend(['-k', key_type])
 
+            if key_type.lower() == 'ec':
+                # This is fix for Bugzilla 1544843
+                cmd.extend([
+                    '--keyOpFlagsOn', 'sign',
+                    '--keyOpFlagsOff', 'derive'
+                ])
+
             if key_size:
                 cmd.extend(['-g', str(key_size)])
 
@@ -524,26 +538,22 @@ class NSSDatabase(object):
                 cmd.extend([','.join(usages)])
 
             if generic_exts:
-
                 cmd.extend(['--extGeneric'])
-
-                counter = 0
                 exts = []
 
-                for generic_ext in generic_exts:
-                    data_file = os.path.join(tmpdir, 'csr-ext-%d' % counter)
-                    with open(data_file, 'w') as f:
-                        f.write(generic_ext['data'])
+                for i, ext in enumerate(generic_exts):
+                    data_file = os.path.join(tmpdir, 'csr-ext-%d' % i)
+                    with open(data_file, 'wb') as f:
+                        f.write(ext['data'])
 
-                    critical = ('critical' if generic_ext['critical']
-                                else 'not-critical')
+                    if ext['critical']:
+                        critical = 'critical'
+                    else:
+                        critical = 'not-critical'
 
-                    ext = generic_ext['oid']
-                    ext += ':' + critical
-                    ext += ':' + data_file
-
-                    exts.append(ext)
-                    counter += 1
+                    exts.append(
+                        '{}:{}:{}'.format(ext['oid'], critical, data_file)
+                    )
 
                 cmd.append(','.join(exts))
 
@@ -555,7 +565,7 @@ class NSSDatabase(object):
                                  stdout=subprocess.PIPE,
                                  stderr=subprocess.STDOUT)
 
-            p.communicate(keystroke)
+            p.communicate(keystroke.encode('ascii'))
 
             rc = p.wait()
 
@@ -750,7 +760,7 @@ class NSSDatabase(object):
                              stdout=subprocess.PIPE,
                              stderr=subprocess.STDOUT)
 
-        p.communicate(keystroke)
+        p.communicate(keystroke.encode('ascii'))
 
         rc = p.wait()
 
@@ -820,11 +830,8 @@ class NSSDatabase(object):
         logger.debug('Command: %s', ' '.join(cmd))
         subprocess.check_call(cmd)
 
-    def get_cert(
-            self,
-            nickname,
-            token=None,
-            output_format='pem'):
+    def get_cert(self, nickname, token=None, output_format='pem',
+                 output_text=False):
 
         if output_format == 'pem':
             output_format_option = '-a'
@@ -888,6 +895,8 @@ class NSSDatabase(object):
 
             if output_format == 'base64':
                 cert_data = base64.b64encode(cert_data)
+            if output_text and not isinstance(cert_data, six.string_types):
+                cert_data = cert_data.decode('ascii')
 
             return cert_data
 
