@@ -33,7 +33,7 @@ import org.dogtagpki.legacy.policy.IGeneralNameAsConstraintsConfig;
 import org.dogtagpki.legacy.policy.IGeneralNamesAsConstraintsConfig;
 import org.dogtagpki.legacy.policy.IGeneralNamesConfig;
 import org.dogtagpki.legacy.policy.ISubjAltNameConfig;
-import org.mozilla.jss.CryptoManager.CertificateUsage;
+import org.mozilla.jss.CertificateUsage;
 import org.mozilla.jss.util.PasswordCallback;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -53,7 +53,6 @@ import com.netscape.certsrv.base.ISecurityDomainSessionTable;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.ca.ICRLIssuingPoint;
 import com.netscape.certsrv.ca.ICertificateAuthority;
-import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.connector.IHttpConnection;
 import com.netscape.certsrv.connector.IPKIMessage;
 import com.netscape.certsrv.connector.IRemoteAuthority;
@@ -119,7 +118,7 @@ public final class CMS {
     public static final int DEBUG_VERBOSE = 5;
     public static final int DEBUG_INFORM = 10;
 
-    private static final String CONFIG_FILE = "CS.cfg";
+    public static final String CONFIG_FILE = "CS.cfg";
     private static ICMSEngine _engine = null;
 
     public static final String SUBSYSTEM_LOG = ILogSubsystem.ID;
@@ -149,6 +148,10 @@ public final class CMS {
         _engine = engine;
     }
 
+    public static ICMSEngine getCMSEngine() {
+        return _engine;
+    }
+
     /**
      * This method is used for unit tests. It allows the underlying _engine
      * to be stubbed out.
@@ -159,51 +162,6 @@ public final class CMS {
         _engine = engine;
     }
 
-    /**
-     * Gets this ID .
-     *
-     * @return CMS engine identifier
-     */
-    public static String getId() {
-        return _engine.getId();
-    }
-
-    /**
-     * Sets the identifier of this subsystem. Should never be called.
-     * Returns error.
-     *
-     * @param id CMS engine identifier
-     */
-    public static void setId(String id) throws EBaseException {
-        _engine.setId(id);
-    }
-
-    /**
-     * Initialize all static, dynamic and final static subsystems.
-     *
-     * @param owner null
-     * @param config main config store.
-     * @exception EBaseException if any error occur in subsystems during
-     *                initialization.
-     */
-    public static void init(ISubsystem owner, IConfigStore config)
-            throws EBaseException {
-        _engine.init(owner, config);
-    }
-
-    public static void reinit(String id) throws EBaseException {
-        _engine.reinit(id);
-    }
-
-    /**
-     * Starts up all subsystems. subsystems must be initialized.
-     *
-     * @exception EBaseException if any subsystem fails to startup.
-     */
-    public static void startup() throws EBaseException {
-        _engine.startup();
-    }
-
     /**
      * Blocks all new incoming requests.
      */
@@ -473,15 +431,6 @@ public final class CMS {
         return _engine.getPKCS7(locale, req);
     }
 
-    /**
-     * Returns all the registered subsystems.
-     *
-     * @return a list of ISubsystem-based subsystems
-     */
-    public static Enumeration<ISubsystem> getSubsystems() {
-        return _engine.getSubsystems();
-    }
-
     /**
      * Retrieves the registered subsytem with the given name.
      *
@@ -492,28 +441,6 @@ public final class CMS {
         return _engine.getSubsystem(name);
     }
 
-    /**
-     * Enable the subsystem with the given ID.
-     *
-     * Does not start the subsystem.
-     *
-     * @param id Subsystem ID.
-     */
-    public static void enableSubsystem(String id) throws EBaseException {
-        _engine.setSubsystemEnabled(id, true);
-    }
-
-    /**
-     * Disable the subsystem with the given ID.
-     *
-     * Does not stop the subsystem.
-     *
-     * @param id Subsystem ID.
-     */
-    public static void disableSubsystem(String id) throws EBaseException {
-        _engine.setSubsystemEnabled(id, false);
-    }
-
     /**
      * Retrieves the localized user message from UserMessages.properties.
      *
@@ -1587,45 +1514,6 @@ public final class CMS {
         return _engine.getCommandQueue();
     }
 
-    /**
-     * Loads the configuration file and starts CMS's core implementation.
-     *
-     * @param path path to configuration file (CMS.cfg)
-     * @exception EBaseException failed to start CMS
-     */
-    public static void start(String path) throws EBaseException {
-
-        String classname = "com.netscape.cmscore.apps.CMSEngine";
-
-        try {
-            ICMSEngine engine = (ICMSEngine)
-                    Class.forName(classname).newInstance();
-
-            CMS.setCMSEngine(engine);
-            IConfigStore mainConfig = createFileConfigStore(path);
-            CMS.init(null, mainConfig);
-            CMS.startup();
-
-        } catch (EBaseException e) { // catch everything here purposely
-            CMS.debug(e);
-
-            // Raidzilla Bug #57592:  Always print error message to stdout.
-            System.out.println(e);
-
-            CMS.debug("CMS.start(): shutdown server");
-
-            shutdown();
-            throw e;
-
-        } catch (Exception e) { // catch everything here purposely
-            CMS.debug(e);
-            System.out.println(Constants.SERVER_SHUTDOWN_MESSAGE);
-
-            throw new EBaseException(e);
-            // cms.shutdown();
-        }
-    }
-
     public static IConfigStore createFileConfigStore(String path) throws EBaseException {
         return _engine.createFileConfigStore(path);
     }
@@ -1674,45 +1562,4 @@ public final class CMS {
     public static boolean isExcludedLdapAttr(String key) {
         return _engine.isExcludedLdapAttr(key);
     }
-
-    /**
-     * Main driver to start CMS.
-     */
-    public static void main(String[] args) {
-        String path = CONFIG_FILE;
-
-        for (int i = 0; i < args.length; i++) {
-            String arg = args[i];
-
-            if (arg.equals("-f")) {
-                path = args[++i];
-            } else {
-                // ignore unknown arguments since we
-                // have no real way to report them
-            }
-        }
-        try {
-            start(path);
-        } catch (EBaseException e) {
-        }
-
-        // Use shutdown hook in stand-alone application
-        // to catch SIGINT, SIGTERM, or SIGHUP.
-        Runtime.getRuntime().addShutdownHook(new Thread() {
-            public void run() {
-                /*LogDoc
-                *
-                * @phase watchdog check
-                */
-                CMS.getLogger().log(ILogger.EV_SYSTEM,
-                        ILogger.S_OTHER,
-                        ILogger.LL_INFO,
-                        "CMSEngine: Received shutdown signal");
-
-                CMS.debug("CMS.main(): shutdown server");
-
-                CMS.shutdown();
-            };
-        });
-    }
 }
