@@ -17,14 +17,34 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.certsrv.common.*;
-import com.netscape.management.client.util.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import java.awt.*;
-import java.util.*;
-import java.awt.event.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
+import java.util.StringTokenizer;
+
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JPasswordField;
+import javax.swing.JTextField;
+
+import com.netscape.admin.certsrv.CMSAdminResources;
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.CMSBaseResourceModel;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.UtilConsoleGlobals;
 
 /**
  * LDAP server setting tab
@@ -58,9 +78,9 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
     private String mPublishingQueuePageSize = "40";
     private String mPublishingQueueStatus = "200";
     private JLabel mAuthLabel, mCertLabel;
-    private JComboBox mAuthBox, mCertBox;
+    private JComboBox<String> mAuthBox, mCertBox;
     private String mPanelName;
-    private JComboBox mVersionBox;
+    private JComboBox<String> mVersionBox;
     private final static String[] AUTHTYPE = {Constants.PR_BASIC_AUTH,
       Constants.PR_SSL_AUTH};
 
@@ -91,9 +111,9 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         mEnablePublishing = makeJCheckBox("ENABLEPUBLISHING");
         mEnablePublishing.setSelected(true);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,
                                 DIFFERENT_COMPONENT_SPACE,
@@ -107,9 +127,9 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         mEnableQueue = makeJCheckBox("ENABLEQUEUE");
         mEnableQueue.setSelected(true);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,
                                 DIFFERENT_COMPONENT_SPACE,
@@ -123,9 +143,9 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         mEnable = makeJCheckBox("ENABLE");
         mEnable.setSelected(true);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,
                                 DIFFERENT_COMPONENT_SPACE,
@@ -138,9 +158,9 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
 
         //add the destination panel
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb.setConstraints(serverInfo, gbc);
@@ -161,8 +181,8 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         // add port number label
         CMSAdminUtil.resetGBC(gbc);
         mPortLabel = makeJLabel("PORT");
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         gb1.setConstraints(mPortLabel, gbc);
         serverInfo.add(mPortLabel);
@@ -170,8 +190,8 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         // add port number text field
         CMSAdminUtil.resetGBC(gbc);
         mPortText = makeJTextField(10);
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 0.0;
         gb1.setConstraints(mPortText, gbc);
         serverInfo.add(mPortText);
@@ -179,10 +199,10 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
         // add check box
         CMSAdminUtil.resetGBC(gbc);
         mSecurePort = makeJCheckBox("SECUREPORT");
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 0.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE - COMPONENT_SPACE,0,COMPONENT_SPACE);
         gb1.setConstraints(mSecurePort, gbc);
         serverInfo.add(mSecurePort);
@@ -329,7 +349,7 @@ public abstract class CMSBaseLDAPPanel extends CMSBaseTab implements ItemListene
                 StringTokenizer tokenizer = new StringTokenizer(certNames,
                   DELIMITER);
                 for (int index=0; tokenizer.hasMoreTokens(); index++) {
-                    String str = (String)tokenizer.nextToken();
+                    String str = tokenizer.nextToken();
                     if (str.startsWith(SERVER_CERT_NICKNAME))
                         serverCertIndex = index;
                     mCertBox.addItem(str);
