@@ -17,15 +17,29 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.certsrv.common.*;
-import com.netscape.management.client.util.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import java.awt.*;
-import java.awt.event.*;
-import java.util.*;
-import java.math.*;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.event.ActionEvent;
+import java.awt.event.ItemListener;
+import java.math.BigInteger;
+import java.util.StringTokenizer;
+import java.util.Vector;
+
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JTextField;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.CMSBaseResourceModel;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.Debug;
 
 /**
  * RA General Setting
@@ -42,14 +56,13 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
     private JCheckBox mEEEnable;
     private JCheckBox mOCSPEnable;
     private CMSTabPanel mParent;
-    private JComboBox mGroups;
-    private JComboBox mAlgorithms;
+    private JComboBox<String> mAlgorithms;
     private JTextField mSerialNumber;
     private JTextField mMaxSerialNumber;
     private JCheckBox mValidity;
     private JCheckBox mEnableSerialNumberManagement;
     private JCheckBox mEnableRandomSerialNumbers;
-    private Vector mGroupData;
+    private Vector<Object> mGroupData;
     private static final String HELPINDEX =
       "configuration-ca-general-help";
 
@@ -90,8 +103,8 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         mCenterPanel.setLayout(gb);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         gbc.weightx = 1.0;
         //gbc.weighty = 1.0;
@@ -99,23 +112,23 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
        // mCenterPanel.add(adminPanel);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gb.setConstraints(validityPanel, gbc);
         mCenterPanel.add(validityPanel);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gb.setConstraints(serialPanel, gbc);
         mCenterPanel.add(serialPanel);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb.setConstraints(signingPanel, gbc);
@@ -123,7 +136,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         mEEEnable = makeJCheckBox("EE");
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         // gbc.gridwidth = gbc.REMAINDER;
         // gbc.gridheight = gbc.REMAINDER;
         gbc.weightx = 1.0;
@@ -133,9 +146,9 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         mOCSPEnable = makeJCheckBox("OCSP");
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb1.setConstraints(mOCSPEnable, gbc);
@@ -144,7 +157,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 		// add validity block
         CMSAdminUtil.resetGBC(gbc);
         mValidity = makeJCheckBox("VALIDITY");
-        gbc.anchor = gbc.CENTER;
+        gbc.anchor = GridBagConstraints.CENTER;
         //gbc.gridwidth = gbc.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         //gbc.weightx = 1.0;
@@ -154,9 +167,9 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel dummy4 = new JLabel(" ");
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb4.setConstraints(dummy4, gbc);
@@ -164,16 +177,16 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel signingLabel = makeJLabel("ALGORITHM");
-        gbc.anchor = gbc.CENTER;
+        gbc.anchor = GridBagConstraints.CENTER;
         gb2.setConstraints(signingLabel, gbc);
         gbc.weighty = 1.0;
         signingPanel.add(signingLabel);
 
         CMSAdminUtil.resetGBC(gbc);
-        mAlgorithms = new JComboBox();
+        mAlgorithms = new JComboBox<>();
         mAlgorithms.addItemListener(this);
         //mAlgorithms = makeJComboBox("ALGORITHM");
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         //gbc.gridwidth = gbc.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         //gbc.weightx = 1.0;
@@ -183,9 +196,9 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel dummy1 = new JLabel(" ");
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb2.setConstraints(dummy1, gbc);
@@ -195,8 +208,8 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         CMSAdminUtil.resetGBC(gbc);
         mEnableSerialNumberManagement = makeJCheckBox("MANAGEMENT");
         //mEnableSerialNumberManagement.setEnabled(false);
-        gbc.anchor = gbc.CENTER;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.CENTER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.gridheight = 1;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
@@ -208,9 +221,9 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         // add random serial numbers
         CMSAdminUtil.resetGBC(gbc);
         mEnableRandomSerialNumbers = makeJCheckBox("RANDOM");
-        gbc.anchor = gbc.CENTER;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER; //1;
+        gbc.anchor = GridBagConstraints.CENTER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER; //1;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gbc.gridx = 0;
@@ -222,7 +235,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         CMSAdminUtil.resetGBC(gbc);
         JLabel serialLabel = makeJLabel("SERIAL");
         serialLabel.setEnabled(false);
-        gbc.anchor = gbc.CENTER;
+        gbc.anchor = GridBagConstraints.CENTER;
         gb3.setConstraints(serialLabel, gbc);
         gbc.gridwidth = 1;
         gbc.gridheight = 1;
@@ -235,7 +248,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         CMSAdminUtil.resetGBC(gbc);
         mSerialNumber = makeJTextField(17);
         mSerialNumber.setEnabled(false);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.gridwidth = 1;
         gbc.gridheight = 1;
         gbc.weightx = 0.0;
@@ -249,7 +262,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         CMSAdminUtil.resetGBC(gbc);
         JLabel maxSerialLabel = makeJLabel("MAXSERIAL");
         maxSerialLabel.setEnabled(false);
-        gbc.anchor = gbc.CENTER;
+        gbc.anchor = GridBagConstraints.CENTER;
         gbc.gridwidth = 1;
         gbc.gridheight = 1;
         gbc.weightx = 0.0;
@@ -262,7 +275,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         CMSAdminUtil.resetGBC(gbc);
         mMaxSerialNumber = makeJTextField(17);
         mMaxSerialNumber.setEnabled(false);
-        gbc.anchor = gbc.CENTER;
+        gbc.anchor = GridBagConstraints.CENTER;
         gbc.gridwidth = 1;
         gbc.gridheight = 1;
         gbc.weightx = 0.0;
@@ -274,9 +287,9 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel dummy2 = new JLabel(" ");
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb3.setConstraints(dummy2, gbc);
@@ -430,7 +443,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
         nvps.put(Constants.PR_DEFAULT_ALGORITHM,
                 (String) mAlgorithms.getSelectedItem());
 
-        String serial = (String)mSerialNumber.getText().trim();
+        String serial = mSerialNumber.getText().trim();
         try {
 			//if (serial.startsWith("0x")) {
 			serial = hexToDecimal(serial);
@@ -447,7 +460,7 @@ public class CMSCAGeneralPanel extends CMSBaseTab implements ItemListener {
 //        nvps.add(Constants.PR_SERIAL, serial);
 
         String maxserial =
-			(String)mMaxSerialNumber.getText().trim();
+			mMaxSerialNumber.getText().trim();
 		if (maxserial != null && !maxserial.equals("")) {
 			try {
 				//if (serial.startsWith("0x")) {
