@@ -17,17 +17,41 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.ug.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import javax.swing.table.*;
-import java.awt.event.*;
-import java.awt.*;
-import java.util.*;
+import java.awt.BorderLayout;
+import java.awt.Color;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
+import java.util.ResourceBundle;
+import java.util.Vector;
 
-import com.netscape.management.client.util.*;
-import com.netscape.certsrv.common.*;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JDialog;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JScrollPane;
+import javax.swing.JTable;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.table.DefaultTableCellRenderer;
+
+import com.netscape.admin.certsrv.CMSAdminResources;
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.admin.certsrv.ug.CertViewDialog;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.JButtonFactory;
 
 /**
  * Connector Editor
@@ -94,11 +118,11 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         //content panel
         JPanel content = makeContentPanel();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
-        gbc.fill = gbc.BOTH;
+        gbc.fill = GridBagConstraints.BOTH;
         //gbc.insets = CMSAdminUtil.DEFAULT_EMPTY_INSETS;
         gb.setConstraints(content, gbc);
         center.add(content);
@@ -116,7 +140,7 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
             String snickname = "";
             CMSAdminUtil.quickSort(vals, 0, response.size() - 1);
             for (i=0; i<vals.length; i++) {
-                Vector v = new Vector();
+                Vector<Object> v = new Vector<>();
                 String entry = vals[i];
                 String value = response.get(entry);
 
@@ -152,9 +176,9 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         //action panel
         JPanel action = makeActionPane();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gb.setConstraints(action, gbc);
         center.add(action);
@@ -348,18 +372,18 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel label2 = new JLabel(mName+":");
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gb.setConstraints(label2, gbc);
         mainPanel.add(label2);
 
         CMSAdminUtil.resetGBC(gbc);
         mEnableBox = CMSAdminUtil.makeJCheckBox(mResource, PREFIX,
           "ENABLE", null, false, this);
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
 /*
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE,
@@ -371,8 +395,8 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         CMSAdminUtil.resetGBC(gbc);
         hostLabel = CMSAdminUtil.makeJLabel(mResource, PREFIX,
           "HOST", null);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
@@ -381,10 +405,10 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 
         CMSAdminUtil.resetGBC(gbc);
         mHostText = new JTextField(20);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
 /*
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
@@ -397,8 +421,8 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         CMSAdminUtil.resetGBC(gbc);
         portLabel = CMSAdminUtil.makeJLabel(mResource, PREFIX,
           "PORT", null);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
         gbc.weightx = 0.0;
@@ -407,14 +431,14 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 
         CMSAdminUtil.resetGBC(gbc);
         mPortText = new JTextField(20);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
 /*
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
 */
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         gb.setConstraints(mPortText, gbc);
         mainPanel.add(mPortText);
@@ -422,8 +446,8 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         CMSAdminUtil.resetGBC(gbc);
         timeoutLabel = CMSAdminUtil.makeJLabel(mResource, PREFIX,
           "TIMEOUT", null);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(0, 4*CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
         gbc.weightx = 0.0;
@@ -432,14 +456,14 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 
         CMSAdminUtil.resetGBC(gbc);
         mTimeoutText = new JTextField(20);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
 /*
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
 */
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         gb.setConstraints(mTimeoutText, gbc);
         mTimeoutText.setText("30");
@@ -448,8 +472,8 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         CMSAdminUtil.resetGBC(gbc);
         nicknameLabel = CMSAdminUtil.makeJLabel(mResource, PREFIX,
           "NICKNAME", null);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.insets = new Insets(0, CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
@@ -458,10 +482,10 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 
         CMSAdminUtil.resetGBC(gbc);
         mNicknameText = new JTextField(50);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gb.setConstraints(mNicknameText, gbc);
         mainPanel.add(mNicknameText);
 
@@ -469,13 +493,13 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
         mHeading = createTextArea(mResource.getString(
           PREFIX+"_TEXT_CERTHEADING_LABEL"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.weightx = 1.0;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.insets = new Insets(2*CMSAdminUtil.COMPONENT_SPACE,
           4*CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gb.setConstraints(mHeading, gbc);
         mainPanel.add(mHeading);
 
@@ -513,12 +537,12 @@ public class ConnectorEditor extends JDialog implements ActionListener, MouseLis
 */
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
-        gbc.fill = gbc.BOTH;
+        gbc.fill = GridBagConstraints.BOTH;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
           4*CMSAdminUtil.COMPONENT_SPACE,
           CMSAdminUtil.COMPONENT_SPACE, CMSAdminUtil.COMPONENT_SPACE);
