@@ -17,18 +17,36 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config.install;
 
-import java.awt.*;
-import java.awt.event.*;
-import java.util.*;
-import javax.swing.*;
-import javax.swing.text.*;
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import com.netscape.admin.certsrv.wizard.*;
-import com.netscape.certsrv.common.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
+import java.util.Hashtable;
+import java.util.StringTokenizer;
+
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JDialog;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JPasswordField;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.text.JTextComponent;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.task.CMSConfigCert;
+import com.netscape.admin.certsrv.wizard.IWizardPanel;
+import com.netscape.admin.certsrv.wizard.WizardBasePanel;
+import com.netscape.admin.certsrv.wizard.WizardInfo;
+import com.netscape.certsrv.common.ConfigConstants;
+import com.netscape.certsrv.common.OpDef;
+import com.netscape.certsrv.common.TaskId;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.admin.certsrv.task.*;
-import com.netscape.management.client.console.*;
+import com.netscape.management.client.console.ConsoleInfo;
 
 /**
  * Migration page for installation wizard.
@@ -47,7 +65,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
     private JLabel mPathLbl, mCATokenHeading, mSSLTokenHeading;
     private JLabel mCATokenLbl, mSSLTokenLbl;
     private JTextField mPathText;
-    private JComboBox mCATokenBox, mSSLTokenBox;
+    private JComboBox<String> mCATokenBox, mSSLTokenBox;
     private String[] mTokenInitialized;
     private String[] mTokenLogin;
     private Color mActiveColor;
@@ -88,7 +106,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
         if (mSSLTokenBox.getItemCount() > 0)
             mSSLTokenBox.removeAllItems();
         for (int i=0; i<mCATokenBox.getItemCount(); i++) {
-            String str = (String)mCATokenBox.getItemAt(i);
+            String str = mCATokenBox.getItemAt(i);
             mSSLTokenBox.addItem(str);
         }
         int index = mCATokenBox.getSelectedIndex();
@@ -113,7 +131,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
         return true;
     }
 
-    private void initializeTokenBox(JComboBox tokenBox) {
+    private void initializeTokenBox(JComboBox<String> tokenBox) {
         if (tokenBox.getItemCount() > 0)
             tokenBox.removeAllItems();
 
@@ -121,7 +139,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
         StringTokenizer tokenizer = new StringTokenizer(tokenList, ":");
         int count = tokenizer.countTokens();
         while (tokenizer.hasMoreTokens()) {
-            tokenBox.addItem((String)tokenizer.nextToken());
+            tokenBox.addItem(tokenizer.nextToken());
         }
 
         String initializedList = mWizardInfo.getTokensInit();
@@ -129,7 +147,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
         int i=0;
         mTokenInitialized = new String[count];
         while (tokenizer.hasMoreElements()) {
-            mTokenInitialized[i] = (String)tokenizer.nextToken();
+            mTokenInitialized[i] = tokenizer.nextToken();
             i++;
         }
 
@@ -138,7 +156,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
         i=0;
         mTokenLogin = new String[count];
         while (tokenizer.hasMoreElements()) {
-            mTokenLogin[i] = (String)tokenizer.nextToken();
+            mTokenLogin[i] = tokenizer.nextToken();
             i++;
         }
     }
@@ -229,7 +247,7 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
     }
 
     public boolean concludePanel(WizardInfo info) {
-        Hashtable data = new Hashtable();
+        Hashtable<String, Object> data = new Hashtable<>();
         String caTokenName = "";
         String sslTokenName = "";
         if (mCATokenBox.getSelectedIndex() == 0) {
@@ -419,33 +437,33 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         CMSAdminUtil.resetGBC(gbc);
         mPathLbl = makeJLabel("PATH");
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE,COMPONENT_SPACE);
         add(mPathLbl, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
         mPathText = makeJTextField(30);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE,COMPONENT_SPACE);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         add(mPathText, gbc);
 
         mTransportLbl = makeJLabel("TRANSPORTPASSWORD");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(0, COMPONENT_SPACE,
           COMPONENT_SPACE,COMPONENT_SPACE);
         add(mTransportLbl, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
         mTransportPassword = makeJPasswordField(20);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(0, COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE);
         add(mTransportPassword, gbc);
@@ -475,35 +493,35 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         mCATokenHeading = makeJLabel("SELECTCATOKEN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel1.add(mCATokenHeading, gbc);
 
         mCATokenLbl = makeJLabel("TOKEN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         panel1.add(mCATokenLbl, gbc);
 
-        mCATokenBox = new JComboBox();
+        mCATokenBox = new JComboBox<>();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         //gbc.weightx = 1.0;
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel1.add(mCATokenBox, gbc);
 
         JTextArea dummy1 = createTextArea(" ", 1, 5);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         panel1.add(dummy1, gbc);
 
         JPanel panel1a = new JPanel();
@@ -512,59 +530,59 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         mLogonInitCATokenLbl = new JLabel("Initialize the selected token:");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(0, 0, 0, COMPONENT_SPACE);
         panel1a.add(mLogonInitCATokenLbl, gbc);
 
         mCAPasswdLbl = makeJLabel("PASSWD");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
         panel1a.add(mCAPasswdLbl, gbc);
 
         mCAPassword = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel1a.add(mCAPassword, gbc);
 
         mCAPasswdAgainLbl = makeJLabel("PASSWDAGAIN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
         panel1a.add(mCAPasswdAgainLbl, gbc);
 
         mCAPasswordAgain = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel1a.add(mCAPasswordAgain, gbc);
 
         mCASOPLbl = makeJLabel("SOP");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel1a.add(mCASOPLbl, gbc);
 
         mCASOPPassword = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel1a.add(mCASOPPassword, gbc);
@@ -575,35 +593,35 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         mSSLTokenHeading = makeJLabel("SELECTSSLTOKEN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(0, 0, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel2.add(mSSLTokenHeading, gbc);
 
         mSSLTokenLbl = makeJLabel("TOKEN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         panel2.add(mSSLTokenLbl, gbc);
 
-        mSSLTokenBox = new JComboBox();
+        mSSLTokenBox = new JComboBox<>();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
+        gbc.anchor = GridBagConstraints.WEST;
         //gbc.weightx = 1.0;
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel2.add(mSSLTokenBox, gbc);
 
         JTextArea dummy1a = createTextArea(" ", 1, 5);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         panel2.add(dummy1a, gbc);
 
         JPanel panel2a = new JPanel();
@@ -612,90 +630,90 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         mLogonInitSSLTokenLbl = new JLabel("Initialize the SSL token");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(0, 0, 0, COMPONENT_SPACE);
         panel2a.add(mLogonInitSSLTokenLbl, gbc);
 
         mSSLPasswdLbl = makeJLabel("PASSWD");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
         panel2a.add(mSSLPasswdLbl, gbc);
 
         mSSLPassword = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel2a.add(mSSLPassword, gbc);
 
         mSSLPasswdAgainLbl = makeJLabel("PASSWDAGAIN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, 0,
           COMPONENT_SPACE);
         panel2a.add(mSSLPasswdAgainLbl, gbc);
 
         mSSLPasswordAgain = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
         panel2a.add(mSSLPasswordAgain, gbc);
 
         mSSLSOPLbl = makeJLabel("SOP");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.insets = new Insets(COMPONENT_SPACE, 0, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel2a.add(mSSLSOPLbl, gbc);
 
         mSSLSOPPassword = new JPasswordField();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE);
         panel2a.add(mSSLSOPPassword, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE, COMPONENT_SPACE);
         gbc.weightx = 1.0;
         add(panel1, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE, COMPONENT_SPACE);
         gbc.weightx = 1.0;
         add(panel1a, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE, COMPONENT_SPACE);
         gbc.weightx = 1.0;
         add(panel2, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE, COMPONENT_SPACE);
         gbc.weightx = 1.0;
@@ -703,8 +721,8 @@ class WIMigrationPage extends WizardBasePanel implements IWizardPanel, ItemListe
 
         CMSAdminUtil.resetGBC(gbc);
         JLabel dumLbl = new JLabel("");
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weighty = 1.0;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE,
           COMPONENT_SPACE, COMPONENT_SPACE);
