@@ -17,24 +17,36 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config.install;
 
-import java.io.*;
-import java.net.*;
-import java.awt.*;
-import java.awt.event.*;
-import java.util.*;
-import javax.swing.*;
-import javax.swing.border.*;
-import javax.swing.event.*;
-import javax.swing.text.*;
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import com.netscape.admin.certsrv.wizard.*;
-import com.netscape.certsrv.common.*;
-import com.netscape.admin.certsrv.config.*;
-import com.netscape.admin.certsrv.task.*;
-import com.netscape.management.client.console.*;
-import com.netscape.management.client.comm.*;
-import com.netscape.management.client.util.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.io.ByteArrayInputStream;
+import java.io.InputStream;
+import java.net.URL;
+import java.util.Hashtable;
+import java.util.StringTokenizer;
+
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JDialog;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JTextArea;
+
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.wizard.IWizardPanel;
+import com.netscape.admin.certsrv.wizard.WizardBasePanel;
+import com.netscape.admin.certsrv.wizard.WizardInfo;
+import com.netscape.certsrv.common.ConfigConstants;
+import com.netscape.certsrv.common.OpDef;
+import com.netscape.certsrv.common.TaskId;
+import com.netscape.management.client.comm.CommClient;
+import com.netscape.management.client.comm.CommManager;
+import com.netscape.management.client.comm.CommRecord;
+import com.netscape.management.client.comm.HttpManager;
+import com.netscape.management.client.console.ConsoleInfo;
+import com.netscape.management.client.util.Debug;
 
 /**
  * Setup Single Signon for the installation wizard.
@@ -58,7 +70,7 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
     private boolean kra;
     private String mDBPasswd;
     private String capassword, rapassword, krapassword, sslpassword;
-    private JComboBox mTokenBox;
+    private JComboBox<String> mTokenBox;
     private static final String START_TASK_CGI = "Tasks/Operation/start";
     private static final String PREFIX = "CGITASK";
     private boolean mFinished = false;
@@ -179,7 +191,7 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
 
         HttpManager h = new HttpManager();
         // tell the http manager to use UTF8 encoding
-        h.setSendUTF8(true);
+        CommManager.setSendUTF8(true);
 
         try {
             mSuccess = false;
@@ -187,7 +199,7 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
 
             // _consoleInfo.get("arguments") is a hashtable of key/value pairs
             // to use as the arguments to the CGI
-            Hashtable args = (Hashtable)_consoleInfo.get("arguments");
+            Hashtable<String, Object> args = (Hashtable<String, Object>)_consoleInfo.get("arguments");
             ByteArrayInputStream data = null;
             if (args != null && !args.isEmpty())
                 data = com.netscape.admin.certsrv.task.CGITask.encode(args);
@@ -281,7 +293,7 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
      */
     public String username(Object authObject, CommRecord cr) {
         Debug.println( "username = " +
-            (String)_consoleInfo.getAuthenticationDN());
+            _consoleInfo.getAuthenticationDN());
         return _consoleInfo.getAuthenticationDN();
     }
 
@@ -299,7 +311,7 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
     public boolean startServer(InstallWizardInfo info) {
         _consoleInfo = info.getAdminConsoleInfo();
 
-        Hashtable configParams = new Hashtable();
+        Hashtable<String, Object> configParams = new Hashtable<>();
         configParams.put("serverRoot",_consoleInfo.get("serverRoot"));
         String servid = (String)_consoleInfo.get("servid");
         int index = servid.indexOf("-");
@@ -438,12 +450,12 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
         JTextArea desc = createTextArea(mResource.getString(
           PANELNAME+"_TEXT_HEADING_LABEL"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         add(desc, gbc);
 
 /*
@@ -464,33 +476,33 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
         JTextArea heading = createTextArea(mResource.getString(
           PANELNAME+"_TEXT_HEADING1_LABEL"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         //gbc.fill = gbc.NONE;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(2*COMPONENT_SPACE, COMPONENT_SPACE, COMPONENT_SPACE, 0);
         add(heading, gbc);
 
         JLabel tokenLbl = makeJLabel("TOKEN");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         //gbc.gridwidth = gbc.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, 4*COMPONENT_SPACE, 0, COMPONENT_SPACE);
         add(tokenLbl, gbc);
 
-        mTokenBox = new JComboBox();
+        mTokenBox = new JComboBox<>();
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         //gbc.gridwidth = gbc.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0, 0);
         add(mTokenBox, gbc);
 
         JLabel dum = new JLabel(" ");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.fill = gbc.BOTH;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.fill = GridBagConstraints.BOTH;
         gbc.weightx = 1.0;
         gbc.insets = new Insets(COMPONENT_SPACE, COMPONENT_SPACE, 0, 0);
         add(dum, gbc);
@@ -498,30 +510,30 @@ class WISingleSignonPage extends WizardBasePanel implements IWizardPanel, CommCl
         JTextArea passwordConfText = createTextArea(mResource.getString(
           PANELNAME+"_TEXT_PASSWDCONF_LABEL"));
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gbc.insets = new Insets(4*COMPONENT_SPACE,COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         add(passwordConfText, gbc);
 
 	mPasswordConf = makeJCheckBox("PASSWDCONF");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gbc.insets = new Insets(COMPONENT_SPACE,2*COMPONENT_SPACE, 0,
           COMPONENT_SPACE);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
 	add(mPasswordConf, gbc);
 
         JLabel dummy = new JLabel(" ");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
-        gbc.fill = gbc.BOTH;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
+        gbc.fill = GridBagConstraints.BOTH;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         add(dummy, gbc);
