@@ -48,13 +48,14 @@ import org.mozilla.jss.ssl.SSLClientCertificateSelectionCallback;
 import org.mozilla.jss.ssl.SSLHandshakeCompletedEvent;
 import org.mozilla.jss.ssl.SSLSocket;
 import org.mozilla.jss.ssl.SSLSocketListener;
+import org.mozilla.jss.ssl.SSLVersion;
+import org.mozilla.jss.ssl.SSLVersionRange;
 import org.mozilla.jss.util.Password;
 import org.mozilla.jss.util.PasswordCallback;
 import org.mozilla.jss.util.PasswordCallbackInfo;
 
 import com.netscape.admin.certsrv.CMSAdminResources;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.crypto.CryptoUtil.SSLVersion;
 import com.netscape.management.client.util.AbstractDialog;
 import com.netscape.management.client.util.Debug;
 import com.netscape.management.client.util.GridBagUtil;
@@ -124,8 +125,10 @@ public class JSSConnection implements IConnection, SSLCertificateApprovalCallbac
         } catch (Exception e) {
         }
 
-        CryptoUtil.setSSLStreamVersionRange(SSLVersion.TLS_1_0, SSLVersion.TLS_1_2);
-        CryptoUtil.setSSLDatagramVersionRange(SSLVersion.TLS_1_1, SSLVersion.TLS_1_2);
+        SSLVersionRange streamRange = CryptoUtil.boundSSLStreamVersionRange(SSLVersion.TLS_1_0, SSLVersion.TLS_1_2);
+        SSLVersionRange datagramRange = CryptoUtil.boundSSLDatagramVersionRange(SSLVersion.TLS_1_1, SSLVersion.TLS_1_2);
+        CryptoUtil.setSSLStreamVersionRange(streamRange.getMinVersion(), streamRange.getMaxVersion());
+        CryptoUtil.setSSLDatagramVersionRange(datagramRange.getMinVersion(), datagramRange.getMaxVersion());
         CryptoUtil.setDefaultSSLCiphers();
 
         s = new SSLSocket(host, port, null, 0, this, this);
@@ -186,7 +189,7 @@ public class JSSConnection implements IConnection, SSLCertificateApprovalCallbac
             return mCertAccepted;
         }
 
-        Enumeration errors = status.getReasons();
+        Enumeration<ValidityItem> errors = status.getReasons();
         //if there are more then 1 error we need to propmt user for trust
         promptForTrust = errors.hasMoreElements();
 
@@ -303,7 +306,7 @@ public class JSSConnection implements IConnection, SSLCertificateApprovalCallbac
         return mServerCertImported;
     }
 
-    public String select(Vector nicknames)
+    public String select(Vector<String> nicknames)
     {
         selectCertDialog = null;
         mClientAuth = true;
@@ -752,7 +755,7 @@ public class JSSConnection implements IConnection, SSLCertificateApprovalCallbac
 
 	class SelectCertDialog extends AbstractDialog {
 
-        JComboBox certList = new JComboBox();
+        JComboBox<String> certList = new JComboBox<>();
 	    protected ResourceBundle mResource = ResourceBundle.getBundle(
           CMSAdminResources.class.getName());
         public SelectCertDialog() {
@@ -778,9 +781,9 @@ public class JSSConnection implements IConnection, SSLCertificateApprovalCallbac
             pack();
         }
 
-        public void setCertList(Vector nicknames) {
+        public void setCertList(Vector<String> nicknames) {
             certList.removeAllItems();
-            Enumeration enum1 = nicknames.elements();
+            Enumeration<String> enum1 = nicknames.elements();
             while (enum1.hasMoreElements()) {
                 certList.insertItemAt(enum1.nextElement(), 0);
             }
