@@ -22,11 +22,6 @@ import javax.swing.border.*;
 
 import java.awt.*;
 import java.awt.event.*;
-import java.util.*;
-
-import com.netscape.management.client.console.ConsoleInfo;
-
-
 import com.netscape.management.client.util.*;
 import com.netscape.management.nmclf.*;
 
@@ -157,7 +152,7 @@ class CertInfoDialog extends AbstractDialog implements SuiConstants {
                     _taskInfo.put("alias", alias);
                     Response response = null;
                     try {
-                        response = _taskInfo.exec(_taskInfo.SEC_ECRT);
+                        response = _taskInfo.exec(KeyCertTaskInfo.SEC_ECRT);
                     } catch (Exception error) {
                         SuiOptionPane.showMessageDialog(
                                 UtilConsoleGlobals.getActivatedFrame(),
@@ -192,7 +187,7 @@ class CertInfoDialog extends AbstractDialog implements SuiConstants {
                     _taskInfo.put("alias", alias);
                     Response response = null;
                     try {
-                        response = _taskInfo.exec(_taskInfo.SEC_ECRT);
+                        response = _taskInfo.exec(KeyCertTaskInfo.SEC_ECRT);
                     } catch (Exception error2) {
                         SuiOptionPane.showMessageDialog(
                                 UtilConsoleGlobals.getActivatedFrame(),
