@@ -46,9 +46,11 @@ import org.apache.commons.lang.StringUtils;
 import org.dogtagpki.common.Info;
 import org.dogtagpki.common.InfoClient;
 import org.mozilla.jss.CryptoManager;
-import org.mozilla.jss.CryptoManager.NotInitializedException;
+import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.ssl.SSLCertificateApprovalCallback;
+import org.mozilla.jss.ssl.SSLVersion;
+import org.mozilla.jss.ssl.SSLVersionRange;
 import org.mozilla.jss.util.IncorrectPasswordException;
 import org.mozilla.jss.util.Password;
 
@@ -57,12 +59,13 @@ import com.netscape.certsrv.client.ClientConfig;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.client.PKIConnection;
 import com.netscape.cmstools.ca.CACLI;
-import com.netscape.cmstools.ca.CACertCLI;
+import com.netscape.cmstools.cert.ProxyCertCLI;
 import com.netscape.cmstools.client.ClientCLI;
 import com.netscape.cmstools.group.ProxyGroupCLI;
-import com.netscape.cmstools.key.KeyCLI;
+import com.netscape.cmstools.key.ProxyKeyCLI;
 import com.netscape.cmstools.kra.KRACLI;
 import com.netscape.cmstools.ocsp.OCSPCLI;
+import com.netscape.cmstools.pkcs11.PKCS11CLI;
 import com.netscape.cmstools.pkcs12.PKCS12CLI;
 import com.netscape.cmstools.pkcs7.PKCS7CLI;
 import com.netscape.cmstools.system.SecurityDomainCLI;
@@ -70,7 +73,6 @@ import com.netscape.cmstools.tks.TKSCLI;
 import com.netscape.cmstools.tps.TPSCLI;
 import com.netscape.cmstools.user.ProxyUserCLI;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.crypto.CryptoUtil.SSLVersion;
 
 /**
  * @author Endi S. Dewata
@@ -107,9 +109,9 @@ public class MainCLI extends CLI {
 
         addModule(new ClientCLI(this));
 
-        addModule(new ProxyCLI(new CACertCLI(this), "ca"));
+        addModule(new ProxyCertCLI(this));
         addModule(new ProxyGroupCLI(this));
-        addModule(new ProxyCLI(new KeyCLI(this), "kra"));
+        addModule(new ProxyKeyCLI(this));
         addModule(new ProxyCLI(new SecurityDomainCLI(this), "ca"));
         addModule(new ProxyUserCLI(this));
 
@@ -120,6 +122,7 @@ public class MainCLI extends CLI {
         addModule(new TPSCLI(this));
 
         addModule(new PKCS7CLI(this));
+        addModule(new PKCS11CLI(this));
         addModule(new PKCS12CLI(this));
 
         createOptions();
@@ -514,6 +517,9 @@ public class MainCLI extends CLI {
             } catch (IncorrectPasswordException e) {
                 // The original exception doesn't contain a message.
                 throw new Exception("Incorrect password for " + tokenName + " token", e);
+
+            } finally {
+                password.clear();
             }
 
         } else {
@@ -533,6 +539,9 @@ public class MainCLI extends CLI {
                 } catch (IncorrectPasswordException e) {
                     // The original exception doesn't contain a message.
                     throw new Exception("Incorrect password for " + tokenName + " token", e);
+
+                } finally {
+                    password.clear();
                 }
             }
         }
@@ -549,18 +558,20 @@ public class MainCLI extends CLI {
         String streamVersionMin = System.getenv("SSL_STREAM_VERSION_MIN");
         String streamVersionMax = System.getenv("SSL_STREAM_VERSION_MAX");
 
-        CryptoUtil.setSSLStreamVersionRange(
+        SSLVersionRange streamRange = CryptoUtil.boundSSLStreamVersionRange(
                 streamVersionMin == null ? SSLVersion.TLS_1_0 : SSLVersion.valueOf(streamVersionMin),
                 streamVersionMax == null ? SSLVersion.TLS_1_2 : SSLVersion.valueOf(streamVersionMax)
         );
+        CryptoUtil.setSSLStreamVersionRange(streamRange.getMinVersion(), streamRange.getMaxVersion());
 
         String datagramVersionMin = System.getenv("SSL_DATAGRAM_VERSION_MIN");
         String datagramVersionMax = System.getenv("SSL_DATAGRAM_VERSION_MAX");
 
-        CryptoUtil.setSSLDatagramVersionRange(
+        SSLVersionRange datagramRange = CryptoUtil.boundSSLDatagramVersionRange(
                 datagramVersionMin == null ? SSLVersion.TLS_1_1 : SSLVersion.valueOf(datagramVersionMin),
                 datagramVersionMax == null ? SSLVersion.TLS_1_2 : SSLVersion.valueOf(datagramVersionMax)
         );
+        CryptoUtil.setSSLDatagramVersionRange(datagramRange.getMinVersion(), datagramRange.getMaxVersion());
 
         String defaultCiphers = System.getenv("SSL_DEFAULT_CIPHERS");
         if (defaultCiphers == null || Boolean.parseBoolean(defaultCiphers)) {
