@@ -82,6 +82,7 @@ import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.base.SessionContext;
+import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.CMCUserSignedRequestSigVerifyEvent;
 import com.netscape.certsrv.profile.EProfileException;
@@ -496,13 +497,27 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                     // to CMCOutputTemplate so that we can
                                     // have a chance to capture user identification info
                                     if (issuerANY != null) {
+                                        // get CA signing cert
+                                        ICertificateAuthority ca = null;
+                                        ca = (ICertificateAuthority) CMS.getSubsystem("ca");
+                                        X500Name caName = ca.getX500Name();
+
                                         try {
                                             byte[] issuerBytes = issuerANY.getEncoded();
-                                            X500Name issuerName = new X500Name(issuerBytes);
-                                            CMS.debug(method + "revRequest issuer name = " + issuerName.toString());
+                                            X500Name reqIssuerName = new X500Name(issuerBytes);
+                                            String reqIssuerNameStr = reqIssuerName.getName();
+                                            CMS.debug(method + "revRequest issuer name = " + reqIssuerNameStr);
+                                            if (reqIssuerNameStr.equalsIgnoreCase(caName.getName())) {
+                                                // making sure it's identical, even in encoding
+                                                reqIssuerName = caName;
+                                            } else {
+                                                // not this CA; will be bumped off later;
+                                                // make a note in debug anyway
+                                                CMS.debug(method + "revRequest issuer name doesn't match our CA; will be bumped off later;");
+                                            }
                                             // capture issuer principal to be checked against
                                             // cert issuer principal later in CMCOutputTemplate
-                                            auditContext.put(SessionContext.CMC_ISSUER_PRINCIPAL, issuerName);
+                                            auditContext.put(SessionContext.CMC_ISSUER_PRINCIPAL, reqIssuerName);
                                         } catch (Exception e) {
                                             CMS.debug(method + "failed getting issuer from RevokeRequest:" + e.toString());
                                         }
@@ -673,7 +688,6 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                     if (requestCertSubject.equals("")) {
                                         requestCertSubject = ILogger.SIGNED_AUDIT_EMPTY_VALUE;
                                     }
-
                                     authToken.set(AuthToken.TOKEN_CERT_SUBJECT, ss);
                                     auditContext.put(SessionContext.CMC_REQUEST_CERT_SUBJECT, requestCertSubject);
                                     //authToken.set("uid", uid);
@@ -696,15 +710,20 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                     SubjectPublicKeyInfo pkinfo = template.getPublicKey();
                                     PrivateKey.Type keyType = null;
                                     String alg = pkinfo.getAlgorithm();
-                                    BIT_STRING bitString = pkinfo.getSubjectPublicKey();
-                                    byte[] publicKeyData = bitString.getBits();
+                                    byte[] publicKeyData = null;
+
                                     if (alg.equals("RSA")) {
+                                        BIT_STRING bitString = pkinfo.getSubjectPublicKey();
+                                        publicKeyData = bitString.getBits();
                                         CMS.debug(method + "signing key alg=RSA");
                                         keyType = PrivateKey.RSA;
                                         selfsign_pubK = PK11PubKey.fromRaw(keyType, publicKeyData);
                                     } else if (alg.equals("EC")) {
                                         CMS.debug(method + "signing key alg=EC");
                                         keyType = PrivateKey.EC;
+                                        X509Key pubKey = CryptoUtil.getX509KeyFromCRMFMsg(crm);
+                                        CMS.debug(method + "got X509Key ");
+                                        publicKeyData = (pubKey).getEncoded();
                                         selfsign_pubK = PK11ECPublicKey.fromSPKI(/*keyType,*/ publicKeyData);
                                     } else {
                                         msg = "unsupported signature algorithm: " + alg;
@@ -1019,7 +1038,7 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                         SET certs = cmcFullReq.getCertificates();
                         int numCerts = certs.size();
                         X509Certificate[] x509Certs = new X509Certificate[1];
-                        byte[] certByteArray = new byte[0];
+
                         for (int j = 0; j < numCerts; j++) {
                             Certificate certJss = (Certificate) certs.elementAt(j);
                             CertificateInfo certI = certJss.getInfo();
@@ -1034,7 +1053,7 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
                                 ByteArrayOutputStream os = new ByteArrayOutputStream();
 
                                 certJss.encode(os);
-                                certByteArray = os.toByteArray();
+                                os.toByteArray();
 
                                 X509CertImpl tempcert = new X509CertImpl(os.toByteArray());
 
@@ -1154,8 +1173,9 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
 
                         IAuthToken tempToken = new AuthToken(null);
                         netscape.security.x509.X500Name tempPrincipal = (X500Name) x509Certs[0].getSubjectDN();
-                        String ID = tempPrincipal.toString(); //tempToken.get("userid");
+                        String ID = tempPrincipal.getName(); //tempToken.get("userid");
                         CMS.debug(method + " Principal name = " + ID);
+                        authToken.set(IAuthToken.TOKEN_AUTHENTICATED_CERT_SUBJECT, ID);
 
                         BigInteger certSerial = x509Certs[0].getSerialNumber();
                         CMS.debug(method + " verified cert serial=" + certSerial.toString());
@@ -1270,8 +1290,16 @@ public class CMCUserSignedAuth implements IAuthManager, IExtendedPluginInfo,
 
     public void populate(IAuthToken token, IRequest request)
             throws EProfileException {
-        request.setExtData(IProfileAuthenticator.AUTHENTICATED_NAME,
-                token.getInString(AuthToken.TOKEN_CERT_SUBJECT));
+        String method = "CMCUserSignedAuth: populate: ";
+        String authenticatedDN = token.getInString(IAuthToken.TOKEN_AUTHENTICATED_CERT_SUBJECT);
+        if (authenticatedDN != null) {
+            request.setExtData(IProfileAuthenticator.AUTHENTICATED_NAME,
+                    authenticatedDN);
+            CMS.debug(method + "IAuthToken.TOKEN_AUTHENTICATED_CERT_SUBJECT is: "+
+                    authenticatedDN);
+        } else {
+            CMS.debug(method + "AuthToken.TOKEN_AUTHENTICATED_CERT_SUBJECT is null; self-signed?");
+        }
     }
 
     public boolean isSSLClientRequired() {
