@@ -41,7 +41,6 @@ import java.security.PrivateKey;
 import java.security.Provider;
 import java.security.Signature;
 import java.security.SignatureException;
-import java.security.interfaces.DSAPrivateKey;
 import java.security.interfaces.RSAPrivateKey;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
@@ -59,6 +58,7 @@ import javax.servlet.ServletException;
 
 import org.apache.commons.lang.StringUtils;
 import org.mozilla.jss.CryptoManager;
+import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.ObjectNotFoundException;
 import org.mozilla.jss.crypto.TokenException;
@@ -611,10 +611,10 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             mSigningKey = cm.findPrivKeyByCert(cert);
 
             String sigAlgorithm;
-            if (mSigningKey instanceof RSAPrivateKey) {
+            if (mSigningKey.getAlgorithm().equalsIgnoreCase("RSA")) {
                 sigAlgorithm = "SHA-256/RSA";
-            } else if (mSigningKey instanceof DSAPrivateKey) {
-                sigAlgorithm = "SHA-256/DSA";
+            } else if (mSigningKey.getAlgorithm().equalsIgnoreCase("EC")) {
+                sigAlgorithm = "SHA-256/EC";
             } else {
                 throw new NoSuchAlgorithmException("Unknown private key type");
             }
@@ -645,7 +645,7 @@ public class LogFile implements ILogEventListener, IExtendedPluginInfo {
             // get a fresh start with this instance.
             pushSignature();
 
-        } catch (CryptoManager.NotInitializedException nie) {
+        } catch (NotInitializedException nie) {
             setupSigningFailure("BASE_CRYPTOMANAGER_UNINITIALIZED", nie);
         } catch (ObjectNotFoundException onfe) {
             setupSigningFailure("LOG_SIGNING_CERT_NOT_FOUND", onfe);
