@@ -438,10 +438,16 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         context.put("sslClientCertProvider",
                 new SSLClientCertProvider(request));
         CMS.debug("ProfileSubmitCMCServlet: set sslClientCertProvider");
+
+        String auditSubjectID = auditSubjectID();
         if (authenticator != null) {
             try {
                 authToken = authenticate(authenticator, request);
                 // authentication success
+                if (authToken != null) {
+                    auditSubjectID = authToken.getInString(IAuthToken.USER_ID);
+                    context.put(SessionContext.AUTH_TOKEN, authToken);
+                }
             } catch (EBaseException e) {
                 CMCOutputTemplate template = new CMCOutputTemplate();
                 SEQUENCE seq = new SEQUENCE();
@@ -468,6 +474,20 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 } catch (Exception e) {
                     CMS.debug("ProfileSubmitCMCServlet authorization failure: " + e.toString());
                 }
+
+                // CMCAuth should pair with additional authz check as it counts
+                // as pre-approved
+                String authMgrID = authenticator.getName();
+                if (authMgrID.equals("CMCAuth")) {
+                    authzToken = null; // reset authzToken
+                    CMS.debug("ProfileSubmitCMCServlet CMCAuth requires additional authz check");
+                    try {
+                        authzToken = authorize(mAclMethod, authToken,
+                                "certServer.ca.certrequests", "execute");
+                    } catch (Exception e) {
+                        CMS.debug("ProfileSubmitCMCServlet authorization failure: " + e.toString());
+                    }
+                }
             }
 
             if (authzToken == null) {
@@ -486,10 +506,6 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
         }
 
-        String auditSubjectID = auditSubjectID();
-        if (authToken != null) {
-            auditSubjectID = authToken.getInString(IAuthToken.USER_ID);
-        }
         String auditMessage = CMS.getLogMessage(
                 AuditEvent.CMC_REQUEST_RECEIVED,
                 auditSubjectID,
@@ -509,15 +525,33 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             CMS.debug("ProfileSubmitCMCServlet: null it out");
             ctx.set(IAuthManager.CRED_CMC_SIGNING_CERT, "");
         }
-        String signingCertSerialS = (String) authToken.get(IAuthManager.CRED_CMC_SIGNING_CERT);
+
+        String signingCertSerialS = null;
+        if (authToken != null) {
+            signingCertSerialS = (String) authToken.get(IAuthManager.CRED_CMC_SIGNING_CERT);
+        }
         if (signingCertSerialS != null) {
             CMS.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in ctx for CMCUserSignedAuth");
             ctx.set(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
         }
+
+        String tmpSharedTokenAuthenticatedCertSubject = ctx.get(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
+        if (tmpSharedTokenAuthenticatedCertSubject != null) {
+            // unlikely to happen, but do this just in case
+            CMS.debug("ProfileSubmitCMCServlet: found existing TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT in ctx for CMCUserSignedAuth:" + tmpSharedTokenAuthenticatedCertSubject);
+            CMS.debug("ProfileSubmitCMCServlet: null it out");
+            ctx.set(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT, "");
+        }
+
+        String errorCode = null;
+        String errorReason = null;
+        String auditRequesterID = ILogger.UNIDENTIFIED;
+
         try {
             reqs = profile.createRequests(ctx, locale);
         } catch (ECMCBadMessageCheckException e) {
-            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -528,9 +562,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.BAD_MESSAGE_CHECK, s);
-            return;
         } catch (ECMCBadIdentityException e) {
-            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -541,9 +575,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.BAD_IDENTITY, s);
-            return;
         } catch (ECMCPopFailedException e) {
-            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -554,9 +588,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.POP_FAILED, s);
-            return;
         } catch (ECMCBadRequestException e) {
-            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -567,9 +601,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.BAD_REQUEST, s);
-            return;
         } catch (EProfileException e) {
-            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: after createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -580,9 +614,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.INTERNAL_CA_ERROR, s);
-            return;
         } catch (Throwable e) {
-            CMS.debug("ProfileSubmitCMCServlet: createRequests - " + e.toString());
+            errorReason = e.toString();
+            CMS.debug("ProfileSubmitCMCServlet: createRequests - " + errorReason);
             CMCOutputTemplate template = new CMCOutputTemplate();
             SEQUENCE seq = new SEQUENCE();
             seq.addElement(new INTEGER(0));
@@ -593,7 +627,15 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
             template.createFullResponseWithFailedStatus(response, seq,
                     OtherInfo.INTERNAL_CA_ERROR, s);
-            return;
+        }
+
+        if (errorReason != null) {
+            audit(CertRequestProcessedEvent.createFailureEvent(
+                        auditSubjectID,
+                        auditRequesterID,
+                        ILogger.SIGNED_AUDIT_REJECTION,
+                        errorReason));
+                return;
         }
 
         TaggedAttribute attr =
@@ -665,13 +707,11 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             }
         }
 
-        String errorCode = null;
-        String errorReason = null;
-
         ///////////////////////////////////////////////
         // populate request
         ///////////////////////////////////////////////
         for (int k = 0; (!isRevoke) && (provedReq == null) &&(k < reqs.length); k++) {
+            auditRequesterID = auditRequesterID(reqs[k]);
             // adding parameters to request
             setInputsIntoRequest(request, profile, reqs[k]);
 
@@ -700,13 +740,31 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
 
                 tmpCertSerialS = reqs[k].getExtDataInString(IAuthManager.CRED_CMC_SIGNING_CERT);
                 if (tmpCertSerialS != null) {
-                    // unlikely to happenm, but do this just in case
+                    // unlikely to happen, but do this just in case
                     CMS.debug("ProfileSubmitCMCServlet: found existing CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth:" + tmpCertSerialS);
                     CMS.debug("ProfileSubmitCMCServlet: null it out");
                     reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, "");
                 }
                 // put CMCUserSignedAuth authToken in request
                 if (signingCertSerialS != null) {
+                     CMS.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth");
+                     reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
+                 }
+
+                tmpSharedTokenAuthenticatedCertSubject = reqs[k].getExtDataInString(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
+                if (tmpSharedTokenAuthenticatedCertSubject != null) {
+                    // unlikely to happen, but do this just in case
+                    CMS.debug("ProfileSubmitCMCServlet: found existing TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT in request for CMCUserSignedAuth:" + tmpSharedTokenAuthenticatedCertSubject);
+                    CMS.debug("ProfileSubmitCMCServlet: null it out");
+                    reqs[k].setExtData(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT, "");
+                }
+                // put Shared Token authToken in request
+                String st_sbj = (String) ctx.get(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
+                if (st_sbj != null) {
+                    CMS.debug("ProfileSubmitCMCServlet: setting IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT in req for CMCUserSignedAuth");
+                    reqs[k].setExtData(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT, st_sbj);
+                }
+                if (tmpSharedTokenAuthenticatedCertSubject != null) {
                     CMS.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in request for CMCUserSignedAuth");
                     reqs[k].setExtData(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
                 }
@@ -750,7 +808,8 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 profile.populateInput(ctx, reqs[k]);
                 profile.populate(reqs[k]);
             } catch (ECMCPopFailedException e) {
-                CMS.debug("ProfileSubmitCMCServlet: after populate - " + e.toString());
+                errorReason = e.toString();
+                CMS.debug("ProfileSubmitCMCServlet: after populate - " + errorReason);
                 CMCOutputTemplate template = new CMCOutputTemplate();
                 SEQUENCE seq = new SEQUENCE();
                 seq.addElement(new INTEGER(0));
@@ -761,9 +820,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 }
                 template.createFullResponseWithFailedStatus(response, seq,
                         OtherInfo.POP_FAILED, s);
-                return;
             } catch (EProfileException e) {
-                CMS.debug("ProfileSubmitCMCServlet: after populate - " + e.toString());
+                errorReason = e.toString();
+                CMS.debug("ProfileSubmitCMCServlet: after populate - " + errorReason);
                 CMCOutputTemplate template = new CMCOutputTemplate();
                 SEQUENCE seq = new SEQUENCE();
                 seq.addElement(new INTEGER(0));
@@ -774,9 +833,9 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 }
                 template.createFullResponseWithFailedStatus(response, seq,
                         OtherInfo.BAD_REQUEST, s);
-                return;
             } catch (Throwable e) {
-                CMS.debug("ProfileSubmitCMCServlet: after populate - " + e.toString());
+                errorReason = e.toString();
+                CMS.debug("ProfileSubmitCMCServlet: after populate - " + errorReason);
                 //  throw new IOException("Profile " + profileId +
                 //          " cannot populate");
                 CMCOutputTemplate template = new CMCOutputTemplate();
@@ -789,12 +848,18 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 }
                 template.createFullResponseWithFailedStatus(response, seq,
                         OtherInfo.INTERNAL_CA_ERROR, s);
+            }
+
+            if (errorReason != null) {
+                audit(CertRequestProcessedEvent.createFailureEvent(
+                        auditSubjectID,
+                        auditRequesterID,
+                        ILogger.SIGNED_AUDIT_REJECTION,
+                        errorReason));
                 return;
             }
         } //for
 
-        String auditRequesterID = ILogger.UNIDENTIFIED;
-
         try {
             ///////////////////////////////////////////////
             // submit request
