@@ -30,8 +30,8 @@ import java.util.Collection;
 
 import org.apache.commons.lang.StringUtils;
 import org.mozilla.jss.CryptoManager;
-import org.mozilla.jss.CryptoManager.NotInitializedException;
 import org.mozilla.jss.NoSuchTokenException;
+import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.ObjectNotFoundException;
 import org.mozilla.jss.crypto.PrivateKey;
@@ -57,8 +57,15 @@ import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.servlet.base.PKIService;
 import com.netscape.cms.servlet.csadmin.Cert;
 import com.netscape.cms.servlet.csadmin.ConfigurationUtils;
+import com.netscape.cms.servlet.csadmin.ReplicationUtil;
 import com.netscape.cms.servlet.csadmin.SystemCertDataFactory;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.SubsystemInfo;
+import com.netscape.cmscore.authentication.AuthSubsystem;
+import com.netscape.cmscore.authorization.AuthzSubsystem;
+import com.netscape.cmscore.dbs.DBSubsystem;
 import com.netscape.cmscore.security.JssSubsystem;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 import netscape.security.x509.X509CertImpl;
@@ -162,7 +169,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         }
         initializeDatabase(data);
 
-        ConfigurationUtils.reInitSubsystem(csType);
+        reinitSubsystems();
 
         configureCACertChain(data, domainXML);
 
@@ -495,6 +502,8 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
 
     public void handleCerts(Collection<Cert> certs) throws Exception {
 
+        CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
+
         for (Cert cert : certs) {
 
             String tag = cert.getCertTag();
@@ -505,7 +514,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             ConfigurationUtils.handleCert(cert);
 
             if (tag.equals("signing") && subsystem.equals("ca")) {
-                CMS.reinit(ICertificateAuthority.ID);
+                engine.reinit(ICertificateAuthority.ID);
             }
         }
     }
@@ -526,14 +535,27 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             nickname = cdata.getNickname();
         }
 
+        boolean isECC = false;
+        String keyType = cdata.getKeyType();
+
+        logger.debug("SystemConfigService:updateCloneConfiguration: keyType: " + keyType);
+        if("ecc".equalsIgnoreCase(keyType)) {
+            isECC = true;
+        }
         X509Certificate cert = cryptoManager.findCertByNickname(nickname);
         PublicKey pubk = cert.getPublicKey();
-        byte[] exponent = CryptoUtil.getPublicExponent(pubk);
-        byte[] modulus = CryptoUtil.getModulus(pubk);
+        byte[] exponent = null;
+        byte[] modulus = null;
+
+        if (isECC == false) {
+            exponent = CryptoUtil.getPublicExponent(pubk);
+            modulus = CryptoUtil.getModulus(pubk);
+            cs.putString("preop.cert." + tag + ".pubkey.modulus", CryptoUtil.byte2string(modulus));
+            cs.putString("preop.cert." + tag + ".pubkey.exponent", CryptoUtil.byte2string(exponent));
+        }
+
         PrivateKey privk = cryptoManager.findPrivKeyByCert(cert);
 
-        cs.putString("preop.cert." + tag + ".pubkey.modulus", CryptoUtil.byte2string(modulus));
-        cs.putString("preop.cert." + tag + ".pubkey.exponent", CryptoUtil.byte2string(exponent));
         cs.putString("preop.cert." + tag + ".privkey.id", CryptoUtil.encodeKeyID(privk.getUniqueID()));
         cs.putString("preop.cert." + tag + ".keyalgorithm", cdata.getKeyAlgorithm());
         cs.putString("preop.cert." + tag + ".keytype", cdata.getKeyType());
@@ -606,6 +628,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                     ca_hostname = cs.getString("securitydomain.host", "");
                     ca_port = cs.getInteger("securitydomain.httpseeport");
                 }
+                logger.debug("Calculated admin cert profile: " + data.getAdminProfileID());
                 String b64 = ConfigurationUtils.submitAdminCertRequest(ca_hostname, ca_port,
                         data.getAdminProfileID(), data.getAdminCertRequestType(),
                         data.getAdminCertRequest(), adminSubjectDN);
@@ -614,7 +637,9 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
                 admincerts[0] = new X509CertImpl(b);
             }
         }
-        CMS.reinit(IUGSubsystem.ID);
+
+        CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
+        engine.reinit(IUGSubsystem.ID);
 
         IUGSubsystem ug = (IUGSubsystem) CMS.getSubsystem(IUGSubsystem.ID);
         IUser user = ug.getUser(data.getAdminUID());
@@ -636,7 +661,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
         cs.putBoolean("preop.database.reindexData", data.getReindexData());
     }
 
-    public void initializeDatabase(ConfigurationRequest data) {
+    public void initializeDatabase(ConfigurationRequest data) throws EBaseException {
 
         if (data.isClone() && data.getSetupReplication()) {
             String masterhost = "";
@@ -717,19 +742,32 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             cs.commit(false);
 
             if (data.isClone() && data.getSetupReplication()) {
-                logger.debug("Start setting up replication.");
-                ConfigurationUtils.setupReplication();
+                ReplicationUtil.setupReplication();
             }
 
             ConfigurationUtils.populateDBManager();
             ConfigurationUtils.populateVLVIndexes();
 
         } catch (Exception e) {
-            logger.error("Error in populating database: " + e.getMessage(), e);
-            throw new PKIException("Error in populating database: " + e, e);
+            logger.error("Unable to populate database: " + e.getMessage(), e);
+            throw new PKIException("Unable to populate database: " + e.getMessage(), e);
         }
     }
 
+    public void reinitSubsystems() throws EBaseException {
+
+        // Enable subsystems after database initialization.
+        CMSEngine engine = (CMSEngine) CMS.getCMSEngine();
+
+        SubsystemInfo si = engine.staticSubsystems.get(UGSubsystem.ID);
+        si.enabled = true;
+
+        engine.reinit(DBSubsystem.ID);
+        engine.reinit(UGSubsystem.ID);
+        engine.reinit(AuthSubsystem.ID);
+        engine.reinit(AuthzSubsystem.ID);
+    }
+
     public void configureHierarchy(ConfigurationRequest data) {
         if (csType.equals("CA") && !data.isClone()) {
             if (data.getHierarchy().equals("root")) {
@@ -859,7 +897,7 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
             cs.putString("preop.securitydomain.select", "existing");
             cs.putString("securitydomain.select", "existing");
             cs.putString("preop.cert.subsystem.type", "remote");
-            cs.putString("preop.cert.subsystem.profile", "caInternalAuthSubsystemCert");
+            cs.putString("preop.cert.subsystem.profile", data.getSystemCertProfileID("subsystem", "caInternalAuthSubsystemCert"));
             String securityDomainURL = data.getSecurityDomainUri();
             domainXML = logIntoSecurityDomain(data, securityDomainURL);
         }
@@ -937,22 +975,25 @@ public class SystemConfigService extends PKIService implements SystemConfigResou
     }
 
     private void getInstallToken(ConfigurationRequest data, String host, int port) {
-        logger.debug("Getting install token");
-        // log onto security domain and get token
+
+        logger.debug("Getting installation token from security domain");
+
         String user = data.getSecurityDomainUser();
         String pass = data.getSecurityDomainPassword();
         String installToken;
+
         try {
             installToken = ConfigurationUtils.getInstallToken(host, port, user, pass);
         } catch (Exception e) {
-            logger.error("Failed to obtain installation token from security domain: " + e.getMessage(), e);
-            throw new PKIException("Failed to obtain installation token from security domain: " + e, e);
+            logger.error("Unable to get installation token: " + e.getMessage(), e);
+            throw new PKIException("Unable to get installation token: " + e.getMessage(), e);
         }
 
         if (installToken == null) {
-            logger.error("Missing install token");
-            throw new PKIException("Missing install token");
+            logger.error("Missing installation token");
+            throw new PKIException("Missing installation token");
         }
+
         CMS.setConfigSDSessionId(installToken);
     }
 
