@@ -20,7 +20,6 @@
 
 from __future__ import absolute_import
 
-import codecs
 import functools
 import getpass
 import grp
@@ -39,6 +38,7 @@ import ldap.filter
 import pki
 import pki.nssdb
 import pki.util
+import six
 from lxml import etree
 
 INSTANCE_BASE_DIR = '/var/lib/pki'
@@ -213,6 +213,8 @@ class PKISubsystem(object):
         if cert_id:
             cmd.append(cert_id)
 
+        logger.debug('Command: %s', ' '.join(cmd))
+
         subprocess.check_output(
             cmd,
             stderr=subprocess.STDOUT)
@@ -328,8 +330,16 @@ class PKISubsystem(object):
     def save(self):
         sorted_config = sorted(self.config.items(), key=operator.itemgetter(0))
         with io.open(self.cs_conf, 'w') as f:
-            for (key, value) in sorted_config:
-                f.write(u'%s=%s\n' % (key, value))
+            for key, value in sorted_config:
+                if value is None:
+                    # write None as empty value
+                    f.write(u'{0}=\n'.format(key))
+                elif isinstance(value, six.string_types):
+                    f.write(u'{0}={1}\n'.format(key, value))
+                elif isinstance(value, six.integer_types):
+                    f.write(u'{0}={1:d}\n'.format(key, value))
+                else:
+                    raise TypeError((key, value, type(value)))
 
     def is_valid(self):
         return os.path.exists(self.conf_dir)
@@ -497,6 +507,14 @@ class PKISubsystem(object):
 
         return files
 
+    def set_signed_audit_log(self, enable=False, maxFileSize=2000):
+        if enable:
+            self.config['log.instance.SignedAudit.logSigning'] = 'true'
+            self.config['log.instance.SignedAudit.maxFileSize'] = maxFileSize
+        else:
+            self.config['log.instance.SignedAudit.logSigning'] = 'false'
+            self.config['log.instance.SignedAudit.maxFileSize'] = maxFileSize
+
     def __repr__(self):
         return str(self.instance) + '/' + self.name
 
@@ -965,7 +983,8 @@ class PKIInstance(object):
         return os.path.exists(self.banner_file)
 
     def get_banner(self):
-        return codecs.open(self.banner_file, "UTF-8").read().strip()
+        with io.open(self.banner_file) as f:
+            return f.read().strip()
 
     def __repr__(self):
         if self.type == 9:
@@ -1045,15 +1064,15 @@ class PKIServerException(pki.PKIException):
 class Tomcat(object):
 
     @classmethod
-    def get_major_version(cls):
+    def get_version(cls):
 
         # run "tomcat version"
         output = subprocess.check_output(['/usr/sbin/tomcat', 'version'])
         output = output.decode('utf-8')
 
-        # find "Server version: Apache Tomcat/<major version>.<minor version>"
+        # find "Server version: Apache Tomcat/<version>"
         match = re.search(
-            r'^Server version:[^/]*/(\d+).*$',
+            r'^Server version: *.*/(.+)$',
             output,
             re.MULTILINE  # pylint: disable=no-member
         )
@@ -1061,5 +1080,5 @@ class Tomcat(object):
         if not match:
             raise Exception('Unable to determine Tomcat version')
 
-        # return major version
-        return match.group(1)
+        # return version
+        return pki.util.Version(match.group(1))
