@@ -22,12 +22,14 @@ from __future__ import absolute_import
 from __future__ import print_function
 import getopt
 import os
+import re
 import sys
 
 from lxml import etree
 
 import pki.cli
 import pki.server
+import pki.util
 
 
 class MigrateCLI(pki.cli.CLI):
@@ -66,7 +68,7 @@ class MigrateCLI(pki.cli.CLI):
                 instance_name = a
 
             elif o == '--tomcat':
-                tomcat_version = a
+                tomcat_version = pki.util.Version(a)
 
             elif o in ('-v', '--verbose'):
                 self.set_verbose(True)
@@ -85,7 +87,7 @@ class MigrateCLI(pki.cli.CLI):
                 sys.exit(1)
 
         if not tomcat_version:
-            tomcat_version = pki.server.Tomcat.get_major_version()
+            tomcat_version = pki.server.Tomcat.get_version()
 
         if instance_name:
 
@@ -157,14 +159,17 @@ class MigrateCLI(pki.cli.CLI):
 
         document = etree.parse(filename, self.parser)
 
-        if tomcat_version == '7':
-            self.migrate_server_xml_to_tomcat7(document)
+        if tomcat_version >= pki.util.Version('8.5.0'):
+            self.migrate_server_xml_to_tomcat85(instance, document)
 
-        elif tomcat_version == '8':
-            self.migrate_server_xml_to_tomcat8(instance, document)
+        elif tomcat_version >= pki.util.Version('8.0.0'):
+            self.migrate_server_xml_to_tomcat80(instance, document)
+
+        elif tomcat_version >= pki.util.Version('7.0.0'):
+            self.migrate_server_xml_to_tomcat70(document)
 
         elif tomcat_version:
-            print('ERROR: invalid Tomcat version %s' % tomcat_version)
+            print('ERROR: unsupported Tomcat version %s' % tomcat_version)
             self.print_help()
             sys.exit(1)
 
@@ -172,7 +177,7 @@ class MigrateCLI(pki.cli.CLI):
             # xml as UTF-8 encoded bytes
             document.write(f, pretty_print=True, encoding='utf-8')
 
-    def migrate_server_xml_to_tomcat7(self, document):
+    def migrate_server_xml_to_tomcat70(self, document):
         server = document.getroot()
 
         jasper_comment = etree.Comment(
@@ -284,7 +289,7 @@ class MigrateCLI(pki.cli.CLI):
             if valve.get('className') == 'org.apache.catalina.valves.AccessLogValve':
                 valve.set('prefix', 'localhost_access_log.')
 
-    def migrate_server_xml_to_tomcat8(self, instance, document):
+    def migrate_server_xml_to_tomcat80(self, instance, document):
         server = document.getroot()
 
         version_logger_listener = etree.Element('Listener')
@@ -386,8 +391,7 @@ class MigrateCLI(pki.cli.CLI):
         if self.debug:
             print('* updating secure Connector')
 
-        keystore_file = os.path.join(instance.conf_dir, 'keystore.p12')
-        keystore_password_file = os.path.join(instance.conf_dir, 'keystore.pwd')
+        full_name = instance.get_sslserver_cert_nickname()
 
         connectors = server.findall('Service/Connector')
         for connector in connectors:
@@ -401,10 +405,11 @@ class MigrateCLI(pki.cli.CLI):
 
             connector.attrib.pop('sslImplementationName', None)
 
-            connector.set('keystoreType', 'pkcs12')
-            connector.set('keystoreFile', keystore_file)
-            connector.set('keystorePassFile', keystore_password_file)
-            connector.set('keyAlias', 'sslserver')
+            connector.set('keystoreType', 'pkcs11')
+            connector.set('keystoreProvider', 'Mozilla-JSS')
+            connector.attrib.pop('keystoreFile', None)
+            connector.attrib.pop('keystorePassFile', None)
+            connector.set('keyAlias', full_name)
 
             connector.set('trustManagerClassName', 'org.dogtagpki.tomcat.PKITrustManager')
 
@@ -418,6 +423,70 @@ class MigrateCLI(pki.cli.CLI):
                     'className') == 'org.apache.catalina.valves.AccessLogValve':
                 valve.set('prefix', 'localhost_access_log')
 
+    def migrate_server_xml_to_tomcat85(self, instance, document):
+
+        self.migrate_server_xml_to_tomcat80(instance, document)
+
+        server = document.getroot()
+
+        services = server.findall('Service')
+        for service in services:
+
+            children = list(service)
+            for child in children:
+                if isinstance(child, etree._Comment):  # pylint: disable=protected-access
+                    if 'Java HTTP Connector: /docs/config/http.html' in child.text:
+                        child.text = child.text.replace(' (blocking & non-blocking)', '')
+                    elif 'Shared Ports:  Agent, EE, and Admin Secure Port Connector' in child.text:
+                        service.remove(child)
+                    elif 'DO NOT REMOVE - Begin define PKI secure port' in child.text:
+                        service.remove(child)
+                    elif 'DO NOT REMOVE - End define PKI secure port' in child.text:
+                        service.remove(child)
+                    elif 'protocol="AJP/1.3"' in child.text:
+                        child.text = re.sub(r'^ *([^ ]+)=',
+                                            r'               \g<1>=',
+                                            child.text,
+                                            flags=re.MULTILINE)
+
+        if self.debug:
+            print('* adding SSLHostConfig')
+
+        full_name = instance.get_sslserver_cert_nickname()
+
+        connectors = server.findall('Service/Connector')
+        for connector in connectors:
+
+            if connector.get('secure') != 'true':
+                continue
+
+            connector.attrib.pop('sslProtocol', None)
+            connector.attrib.pop('clientAuth', None)
+            connector.attrib.pop('keystoreType', None)
+            connector.attrib.pop('keystoreProvider', None)
+            connector.attrib.pop('keyAlias', None)
+            connector.attrib.pop('trustManagerClassName', None)
+
+            sslHostConfigs = connector.findall('SSLHostConfig')
+            if len(sslHostConfigs) > 0:
+                sslHostConfig = sslHostConfigs[0]
+            else:
+                sslHostConfig = etree.SubElement(connector, 'SSLHostConfig')
+
+            sslHostConfig.set('sslProtocol', 'SSL')
+            sslHostConfig.set('certificateVerification', 'optional')
+            sslHostConfig.set('trustManagerClassName', 'org.dogtagpki.tomcat.PKITrustManager')
+
+            certificates = sslHostConfig.findall('Certificate')
+            if len(certificates) > 0:
+                certificate = certificates[0]
+            else:
+                certificate = etree.SubElement(sslHostConfig, 'Certificate')
+
+            certificate.set('certificateKeystoreType', 'pkcs11')
+            certificate.set('certificateKeystoreProvider', 'Mozilla-JSS')
+            certificate.set('certificateKeyAlias', full_name)
+
     def migrate_subsystems(self, instance, tomcat_version):
         for subsystem in instance.subsystems:
             self.migrate_subsystem(subsystem, tomcat_version)
@@ -437,10 +506,10 @@ class MigrateCLI(pki.cli.CLI):
 
         document = etree.parse(filename, self.parser)
 
-        if tomcat_version == '7':
+        if tomcat_version.major == 7:
             self.migrate_context_xml_to_tomcat7(document)
 
-        elif tomcat_version == '8':
+        elif tomcat_version.major == 8 or tomcat_version.major == 9:
             self.migrate_context_xml_to_tomcat8(document)
 
         elif tomcat_version:
@@ -515,7 +584,8 @@ class MigrateCLI(pki.cli.CLI):
         # slf4j-jdk14.jar
         source = '/usr/share/pki/server/lib/slf4j-jdk14.jar'
         dest = os.path.join(instance.lib_dir, 'slf4j-jdk14.jar')
-        self.create_link(instance, source, dest)
+        if os.path.islink(source):
+            self.create_link(instance, source, dest)
 
     def create_link(self, instance, source, dest):
 
