@@ -78,7 +78,7 @@ DEFAULT_DEPLOYMENT_CONFIGURATION = "default.cfg"
 USER_DEPLOYMENT_CONFIGURATION = "deployment.cfg"
 
 PKI_DEPLOYMENT_DEFAULT_CONFIGURATION_FILE = \
-    PKI_DEPLOYMENT_CONFIGURATION_ROOT + "/" + DEFAULT_DEPLOYMENT_CONFIGURATION
+    PKI_DEPLOYMENT_SOURCE_ROOT + "/server/etc/" + DEFAULT_DEPLOYMENT_CONFIGURATION
 PKI_DEPLOYMENT_SLOTS_CONFIGURATION_FILE = \
     PKI_DEPLOYMENT_SOURCE_ROOT + "/deployment/config/pkislots.cfg"
 
