@@ -267,7 +267,7 @@ class PKIConfigParser:
         default_http_port = '8080'
         default_https_port = '8443'
 
-        application_version = str(pki.upgrade.Version(
+        application_version = str(pki.util.Version(
             pki.implementation_version()))
 
         self.deployer.main_config = configparser.SafeConfigParser({
@@ -541,7 +541,7 @@ class PKIConfigParser:
     def ds_search(self, key=None):
         if key is None:
             key = ''
-        self.ds_connection.search_s(key, ldap.SCOPE_BASE)
+        return self.ds_connection.search_s(key, ldap.SCOPE_BASE)
 
     def ds_close(self):
         self.ds_connection.unbind_s()
@@ -586,9 +586,11 @@ class PKIConfigParser:
         try:
             info = sd.get_security_domain_info()
         except requests.exceptions.HTTPError as e:
+            config.pki_log.warning(
+                'Unable to get security domain info: %s', e,
+                extra=config.PKI_INDENTATION_LEVEL_2)
             config.pki_log.info(
-                "unable to access security domain through REST interface.  " +
-                "Trying old interface. " + str(e),
+                'Trying older interface.',
                 extra=config.PKI_INDENTATION_LEVEL_2)
             info = sd.get_old_security_domain_info()
         return info
@@ -606,8 +608,7 @@ class PKIConfigParser:
             code = e.response.status_code
             if code == 404 or code == 501:
                 config.pki_log.warning(
-                    "unable to validate security domain user/password " +
-                    "through REST interface. Interface not available",
+                    'Unable to authenticate against security domain: %s', e,
                     extra=config.PKI_INDENTATION_LEVEL_2)
             else:
                 raise
@@ -740,9 +741,7 @@ class PKIConfigParser:
                 os.path.join(
                     self.mdict['pki_subsystem_configuration_path'],
                     "CS.cfg")
-            self.mdict['pki_target_registry'] = \
-                os.path.join(self.mdict['pki_instance_registry_path'],
-                             self.mdict['pki_instance_name'])
+
             if config.str2bool(self.mdict['pki_external_step_two']) or\
                config.str2bool(self.mdict['pki_skip_installation']):
                 # For CA (External CA Step 2) and Stand-alone PKI (Step 2),
@@ -871,10 +870,6 @@ class PKIConfigParser:
                 self.mdict['pki_install_time']
             self.mdict['PKI_ADMIN_SECURE_PORT_SLOT'] = \
                 self.mdict['pki_https_port']
-            self.mdict['PKI_ADMIN_SECURE_PORT_CONNECTOR_NAME_SLOT'] = \
-                "Unused"
-            self.mdict['PKI_ADMIN_SECURE_PORT_SERVER_COMMENT_SLOT'] = ""
-            self.mdict['PKI_AGENT_CLIENTAUTH_SLOT'] = "want"
             self.mdict['PKI_AGENT_SECURE_PORT_SLOT'] = \
                 self.mdict['pki_https_port']
             self.mdict['PKI_AJP_PORT_SLOT'] = \
@@ -897,16 +892,12 @@ class PKIConfigParser:
                 self.mdict['pki_ds_secure_connection'].lower()
             self.mdict['PKI_EE_SECURE_CLIENT_AUTH_PORT_SLOT'] = \
                 self.mdict['pki_https_port']
-            self.mdict['PKI_EE_SECURE_CLIENT_AUTH_PORT_CONNECTOR_NAME_SLOT'] = \
-                "Unused"
             self.mdict['PKI_EE_SECURE_CLIENT_AUTH_PORT_SERVER_COMMENT_SLOT'] = \
                 ""
             self.mdict['PKI_EE_SECURE_CLIENT_AUTH_PORT_UI_SLOT'] = \
                 self.mdict['pki_https_port']
             self.mdict['PKI_EE_SECURE_PORT_SLOT'] = \
                 self.mdict['pki_https_port']
-            self.mdict['PKI_EE_SECURE_PORT_CONNECTOR_NAME_SLOT'] = \
-                "Unused"
             self.mdict['PKI_EE_SECURE_PORT_SERVER_COMMENT_SLOT'] = \
                 ""
             self.mdict['PKI_GROUP_SLOT'] = \
