@@ -430,10 +430,32 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             trust_attributes=None):
 
         cert_id = self.get_cert_id(subsystem, tag)
+        param = 'pki_%s_cert_path' % cert_id
+        cert_file = deployer.mdict.get(param)
 
-        cert_file = deployer.mdict.get('pki_%s_cert_path' % cert_id)
-        if not cert_file or not os.path.exists(cert_file):
-            return
+        # Existing/external CA:
+        #  - CA signing cert is mandatory
+        #  - other certs are optional (ignored if missing)
+        #
+        # External/standalone KRA/OCSP:
+        #  - all certs are mandatory
+
+        exists = cert_file and os.path.exists(cert_file)
+
+        if subsystem.name == 'ca':  # existing or external
+
+            if tag == 'signing':
+                if not exists:
+                    raise Exception('Invalid certificate path: %s=%s' % (param, cert_file))
+
+            else:  # other certs
+                if not exists:
+                    return
+
+        elif subsystem.name in ['kra', 'ocsp']:  # external or standalone
+
+            if not exists:
+                raise Exception('Invalid certificate path: %s=%s' % (param, cert_file))
 
         config.pki_log.info(
             "importing %s certificate from %s", cert_id, cert_file,
@@ -562,7 +584,9 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         cert_data = nssdb.get_cert(
             nickname=nickname,
-            output_format='base64')
+            output_format='base64',
+            output_text=True,
+        )
 
         subsystem.config['%s.%s.cert' % (subsystem.name, tag)] = cert_data
 
@@ -623,7 +647,9 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             nickname = deployer.mdict['pki_admin_nickname']
             cert_data = client_nssdb.get_cert(
                 nickname=nickname,
-                output_format='base64')
+                output_format='base64',
+                output_text=True,
+            )
 
             subsystem.config['%s.admin.cert' % subsystem.name] = cert_data
 
@@ -1038,7 +1064,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             json.dumps(data, cls=pki.encoder.CustomTypeEncoder))
 
         config.pki_log.debug(
-            log.PKI_CONFIG_RESPONSE_STATUS + " " + str(response['status']),
+            '%s %s', log.PKI_CONFIG_RESPONSE_STATUS, response['status'],
             extra=config.PKI_INDENTATION_LEVEL_2)
 
         # Create an empty file that designates the fact that although
@@ -1131,13 +1157,13 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
             else:
                 config.pki_log.debug(
-                    log.PKI_CONFIG_CDATA_TAG + " " + cdata['tag'],
+                    '%s %s', log.PKI_CONFIG_CDATA_TAG, cdata['tag'],
                     extra=config.PKI_INDENTATION_LEVEL_2)
                 config.pki_log.debug(
-                    log.PKI_CONFIG_CDATA_CERT + "\n" + cdata['cert'],
+                    '%s\n%s', log.PKI_CONFIG_CDATA_CERT, cdata['cert'],
                     extra=config.PKI_INDENTATION_LEVEL_2)
                 config.pki_log.debug(
-                    log.PKI_CONFIG_CDATA_REQUEST + "\n" + cdata['request'],
+                    '%s\n%s', log.PKI_CONFIG_CDATA_REQUEST, cdata['request'],
                     extra=config.PKI_INDENTATION_LEVEL_2)
 
         # Cloned PKI subsystems do not return an Admin Certificate
