@@ -537,6 +537,8 @@ def main(argv):
         log_error_details()
         print()
         print("Installation failed: Command failed: %s" % ' '.join(e.cmd))
+        if e.output:
+            print(e.output)
         print()
         print('Please check pkispawn logs in %s/%s' % (config.pki_log_dir, config.pki_log_name))
         sys.exit(1)
@@ -626,7 +628,7 @@ def sanitize_user_deployment_cfg(cfg):
     for line in fileinput.FileInput(cfg, inplace=1):
         # Remove extraneous leading and trailing whitespace from all lines
         line = line.strip()
-        # Normalize section headings to match '/etc/pki/default.cfg'
+        # Normalize section headings to match '/usr/share/pki/server/etc/default.cfg'
         if line.startswith("["):
             if line.upper().startswith("[DEFAULT"):
                 line = "[DEFAULT]"
